# config.py
import logging

import typer

from stratio.config import Config


# Set up a logger for the CLI.
def get_logger() -> logging.Logger:
    """Set up a module–level logger."""
    logger = logging.getLogger("StratioCLI")
    if not logger.handlers:
        handler = logging.StreamHandler()
        formatter = logging.Formatter("%(asctime)s - %(levelname)s - %(message)s")
        handler.setFormatter(formatter)
        logger.addHandler(handler)
        logger.setLevel(logging.WARN)
        # Set boto3 and botocore loggers to WARNING level
        logging.getLogger("boto3").setLevel(logging.WARNING)
        logging.getLogger("botocore").setLevel(logging.WARNING)
        logging.getLogger("urllib3").setLevel(logging.ERROR)
    return logger


logger = get_logger()
_config = None


def load_config(config_path: str) -> Config:
    """
    Load the configuration from the specified YAML file.
    """
    try:
        config = Config.load_from_file(config_path)
        logger.info(f"Configuration loaded from {config_path}")
        return config
    except Exception as e:
        logger.error(f"Error loading configuration: {e}")
        raise typer.Exit(1) from e
